︠77efcae7-2194-4666-bc74-2deb8c305867︠
#Simple 1st order differential equation (o.d.e):
#dx/dt=y
#dy/dt=-x
#initial conditions: x=1,y=0

#Let x=sin(t), y=cos(t), and t=pi/2
#Therefore: x(pi/2)=sin(pi/2)=1 and y(pi/2)=cos(pi/2)=0
︡4e0d3a3f-a75d-4402-812f-4cc635a6f43e︡︡
︠19cfd748-fb37-43b1-9dfc-e38d2aba13c8︠
#Exact Solution to o.d.e.
︡ecf75dce-4757-417e-8376-d2248bbdb574︡︡
︠3d714fcc-8c5c-4308-9cfd-77a86c884297︠
t=var('t') #Defines t as a dummy variable.
︡e23840f6-2492-4e29-bc70-d00cce86ee95︡︡
︠71ad51ad-fe96-4c23-8214-a75eb7da1724︠
p1=plot(sin(t),-2*pi,2*pi) #2D Plot of sin(t) vs t.
︡423e0937-2afa-41f7-ab82-4f75b49bdda6︡︡
︠75896cde-6187-4a9f-b6d8-5f4b34237add︠
#Information to display on sin(t) vs t plot:
title=text("2D Plot: sin(t) vs t", (2.6,1.5), rgbcolor='black',vertical_alignment="top")
curve=text("x=sin(t)", (-5,1.2), rgbcolor='black',vertical_alignment="top") 
exact_solution=point((pi/2,1),rgbcolor='red',pointsize=25) #Places red point at exact (initial cond) solution,(pi/2,1)
point_location=text("Exact Solution (pi/2,1)", (3,1.2), rgbcolor='black',vertical_alignment="top")
︡f51b5913-3800-4b7f-aef8-e8aabc63f946︡︡
︠c05306f0-4b15-4893-ab02-3d602030c806︠
show(p1+title+curve+exact_solution+point_location, axes_labels=('t','x'))
︡a950be18-c22d-4143-9001-a2081f256634︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠d2de3fcb-a271-4b85-8277-dcc42c6c747a︠
p2=plot(cos(t),-2*pi,2*pi) #2D plot of cos(t) vs t.
︡beb8e734-2d21-4123-8ea9-d896d961f078︡︡
︠2faa00c5-e3d5-4403-b03c-63f22977716a︠
#Information to display on cos(t) vs t plot:
title=text("2D Plot: cos(t) vs t", (2.65,1.5), rgbcolor='black',vertical_alignment="top")
curve=text("y=cos(t)", (-5,1.2), rgbcolor='black',vertical_alignment="top") 
exact_solution=point((pi/2,0),rgbcolor='red',pointsize=25) #Places red point at exact (initial cond) solution,(pi/2,0)
point_location=text("Exact Solution (pi/2,0)", (3,1.2), rgbcolor='black',vertical_alignment="top")
initial_condition_location=arrow((2,1),(pi/2,0.1), color='red') #Places arrow at location of initial condition
︡7933521c-3999-45e6-9e8f-26a9be0b3a3c︡︡
︠d58297a2-1593-435d-9b22-0da93f75fc79︠
show(p2+title+curve+exact_solution+point_location+initial_condition_location, axes_labels=('t','y'))
︡4f6fb4d5-4007-4a70-a498-700f9b8b2106︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠a8cd1811-4aee-49cf-b36d-3451db06ef33︠
#Use 2nd Order Runge-Kutta to integrate equation dy/dt=-x, where y=cos(t). 
#Therefore, equation to be integrated is -sin(t)+x
︡593a369f-b6ba-4271-9d51-cb8f9eb412cf︡︡
︠57255bd5-a813-4876-b396-38cd4b35f4fa︠
def xfunc(t,x): #x function with independent variable t defined. 
    return float(-sin(t)+x)
︡0ce8109e-a7ab-4815-9f4d-cb395cb73230︡︡
︠9f087ba5-81e4-4a1d-8196-98c955ae6c67︠
import scipy #Transfer files from scipy (open source library of algorithms and mathematical tools from Python programming language) into this worksheet.

def rk2x(x0,t0,tn,dt): #2nd Order Runge-Kutta defined.

    time = scipy.arange(t0,tn,dt) #Creates array range (arange) of time values.
    x=[] #Stores index of refraction values.

    for t in time:
        x.append(x0) #Attach results (x0) at end of variable x.
        k1=xfunc(t,x0)
        k2=xfunc(t+0.5*dt,x0+0.5*k1)
        x0=x0+(k1+k2)/2
    return time,x
︡7d938348-4069-4cc4-b5d2-c85750bf5a0c︡︡
︠fa912027-68a8-4b2c-b49d-f46a5b5923db︠
rk2x(1, float(pi/2), 2, 0.01) #Function call to 2nd Order Runge-Kutta with predetermined assignments.
︡35b50171-f056-4f64-b5f7-81dd4ae7b045︡{"stdout": "(array([ 1.57079633,  1.58079633,  1.59079633,  1.60079633,  1.61079633,\n        1.62079633,  1.63079633,  1.64079633,  1.65079633,  1.66079633,\n        1.67079633,  1.68079633,  1.69079633,  1.70079633,  1.71079633,\n        1.72079633,  1.73079633,  1.74079633,  1.75079633,  1.76079633,\n        1.77079633,  1.78079633,  1.79079633,  1.80079633,  1.81079633,\n        1.82079633,  1.83079633,  1.84079633,  1.85079633,  1.86079633,\n        1.87079633,  1.88079633,  1.89079633,  1.90079633,  1.91079633,\n        1.92079633,  1.93079633,  1.94079633,  1.95079633,  1.96079633,\n        1.97079633,  1.98079633,  1.99079633]), [1, 1.0000062499869791, 1.0001078111035242, 1.0005488118451449, 1.0018785200780911, 1.0053327547560502, 1.013692062286089, 1.0332126133566466, 1.0779707208063913, 1.1796380048362707, 1.4094755147449907, 1.927820502843461, 3.0954316657731566, 5.7240159374845376, 11.639913773451845, 24.952391040170976, 54.907295766545545, 122.30778583452259, 273.96096628304116, 615.18282324193638, 1382.9343252832441, 3110.3776514616584, 6997.1277044055851, 15742.318014772034, 35418.999026270154, 79691.534236964217, 179304.74151720537, 403434.461074978, 907726.3333779294, 2042383.0494779362, 4595360.6642413791, 10339560.30111726, 23264009.48786547, 52344020.161945388, 117774044.18264021, 264991598.23333675, 596231094.85165489, 1341519962.2472391, 3018419913.8917885, 6791444805.0966263, 15280750810.312229, 34381689322.05217, 77358800973.471985])"}︡
︠af4f0b1f-38d0-4cb8-9175-ccbe555525c8︠
t2,x2=rk2x(1, float(pi/2), 2, 0.01) #Variable t2,x2 is assigned time and x values.
︡733bd736-1a53-45fb-a202-742a0104dcbe︡︡
︠8200ec60-5623-4f58-83d1-2931a7dff60a︠
#Information to display on -sin(t)+x plot using RK2:
title=text("RK2 solution of -sin(t)+x", (1.9,88000000000), rgbcolor='black',horizontal_alignment="right")
initial_condition=point((pi/2,1),rgbcolor='red',pointsize=25) #Places red point at initial condition,(pi/2,1)
︡ccdb2456-f72f-4994-b768-08fc821eff2f︡︡
︠975eaa1c-7ac4-45a3-a5fd-ea8f61b62aa1︠
plxtRK2=list_plot(zip(t2,x2),'r')
show(plxtRK2+title+initial_condition, axes_labels=('t','x'))
︡85a38ca7-da4e-4176-9301-638c9af4cdb2︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠8e438bf6-7bbb-4a71-ad6b-d8bcd7e6333e︠
import numpy as np #Transfer files from fundamental library numpy (N-dimensional array manipulation) used with Python.
import matplotlib.pyplot as plt #Transfer files from matplotlib.pyplot (plotting library) used with Python language. 

x = t2
y = x2

fig = plt.figure()
ax = fig.add_subplot(111)
ax.plot(x, y)
ax.set_xlim(1.4, 2.2)
ax.set_ylim(0, 80000000000)
ax.set_xlabel('Increasing time (t)')
ax.set_ylabel('Integrated Eqn: -sin(t)+x')
ax.set_title('RK2 Soln to Integrated Eqn: -sin(t)+x')
ax.grid()

xdata, ydata = 1.92079633, 264991598.23333675
xdisplay, ydisplay = ax.transData.transform((xdata, ydata))

bbox = dict(boxstyle="round", fc="0.8") #bbox or bounding box
arrowprops = dict(arrowstyle = "->",connectionstyle = "angle,angleA=0,angleB=90,rad=10")

offset = 72
ax.annotate('data = (%.1f, %.1f)'%(xdata, ydata),
            (xdata, ydata), xytext=(-3*offset, offset), textcoords='offset points',
            bbox=bbox, arrowprops=arrowprops)

plt.savefig('myfig.png')
︡6f41ad9c-b63f-402e-9fb7-e9ac2b323c08︡︡
︠c247bf25-da64-4a2d-8769-7bb672b24616︠
#Use 4th Order Runge-Kutta to integrate equation dy/dt=-x, where y=cos(t). 
#Therefore, equation to be integrated is -sin(t)+x
︡d14d197a-0611-4515-a63f-a09016f3d833︡︡
︠c5c46b89-f778-4cfc-bdb0-6c5491366bc8︠
import scipy #Transfer files from scipy (open source library of algorithms and mathematical tools from Python programming language) into this worksheet.

def rk4x(x0,t0,tn,dt): #4th Order Runge-Kutta defined.

    time = scipy.arange(t0,tn,dt) #Creates array range (arange) of time values.
    x=[] #Stores index of refraction values.

    for t in time:
   	x.append(x0) #Attach results (x0) at end of variable x.
   	k1 = xfunc(t,x0)
   	k2 = xfunc(t+0.5*dt, x0 + 0.5*dt*k1)
   	k3 = xfunc(t+0.5*dt, x0 + 0.5*dt*k2)
   	k4 = xfunc(t+dt, x0 + dt*k3)
   	x0 = x0+(dt/6.0)*(k1 + 2.0*k2 + 2.0*k3 + k4)
    return time,x
︡81075fb9-34ea-41a4-9dc4-82a6015599e4︡︡
︠d805bcf3-aa31-419e-96c7-a9548f255b18︠
rk4x(1, float(pi/2), 2, 0.01) #Function call to 4th Order Runge-Kutta with predetermined assignments.
︡87f14ad1-d83d-4d5a-985b-f6482703df03︡{"stdout": "(array([ 1.57079633,  1.58079633,  1.59079633,  1.60079633,  1.61079633,\n        1.62079633,  1.63079633,  1.64079633,  1.65079633,  1.66079633,\n        1.67079633,  1.68079633,  1.69079633,  1.70079633,  1.71079633,\n        1.72079633,  1.73079633,  1.74079633,  1.75079633,  1.76079633,\n        1.77079633,  1.78079633,  1.79079633,  1.80079633,  1.81079633,\n        1.82079633,  1.83079633,  1.84079633,  1.85079633,  1.86079633,\n        1.87079633,  1.88079633,  1.89079633,  1.90079633,  1.91079633,\n        1.92079633,  1.93079633,  1.94079633,  1.95079633,  1.96079633,\n        1.97079633,  1.98079633,  1.99079633]), [1, 1.00000016708351, 1.00000134000034, 1.00000453375051, 1.00001077333402, 1.00002109375097, 1.00003654000151, 1.00005816708607, 1.00008704000543, 1.00012423376095, 1.00017083335489, 1.00022793379078, 1.00029664007385, 1.00037806721165, 1.00047334021469, 1.00058359409733, 1.00070997387864, 1.00085363458358, 1.00101574124423, 1.00119746890123, 1.00140000260544, 1.00162453741970, 1.00187227842089, 1.00214444070218, 1.00244224937551, 1.00276693957429, 1.00311975645642, 1.00350195520749, 1.00391480104435, 1.00435956921893, 1.00483754502235, 1.00535002378938, 1.00589831090322, 1.00648372180065, 1.00710758197747, 1.00777122699440, 1.00847600248328, 1.00922326415376, 1.01001437780030, 1.01085071930967, 1.01173367466886, 1.01266463997345, 1.01364502143643])"}︡
︠cab1e1d6-1f34-43fa-b6f4-c47413c43064︠
t4,x4=rk4x(1, float(pi/2), 2, 0.01) #Variable t4,x4 is assigned time and x values.
︡1827cd7f-2261-4c40-a90a-3625eeb92435︡︡
︠f2197895-9aa3-4473-87c5-2526ee3c9f5b︠
#Information to display on -sin(t)+x plot (RK4):
title=text("RK4 solution of -sin(t)+x", (1.8,1.014), rgbcolor='black',vertical_alignment="top")
initial_condition=point((pi/2,1),rgbcolor='red',pointsize=25) #Places red point at initial condition,(pi/2,1)
︡a1d3e4f2-ea50-4ad9-8a32-961cb5ad5fa7︡︡
︠f8c10fcf-c03d-40d7-9510-57fcdd5f8d83︠
plxtRK4=list_plot(zip(t4,x4),'r')
show(plxtRK4+title+initial_condition, axes_labels=('t','x'))
︡b7e3176e-fb23-4ecc-a301-986c3f649c9a︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠d9597f36-91ec-4347-b0b2-3d9b092aa6de︠
import numpy as np #Transfer files from fundamental library numpy (N-dimensional array manipulation) used with Python.
import matplotlib.pyplot as plt #Transfer files from matplotlib.pyplot (plotting library) used with Python language. 

x = t4
y = x4

fig = plt.figure()
ax = fig.add_subplot(111)
ax.plot(x, y)
ax.set_xlim(1.4, 2.2)
ax.set_ylim(1, 1.012)
ax.set_xlabel('Increasing time (t)')
ax.set_ylabel('Integrated Eqn: -sin(t)+x')
ax.set_title('RK4 Soln to Integrated Eqn: -sin(t)+x')
ax.grid()

xdata, ydata = 1.63079633, 1.00003654000151
xdisplay, ydisplay = ax.transData.transform((xdata, ydata))

bbox = dict(boxstyle="round", fc="0.8") #bbox or bounding box
arrowprops = dict(arrowstyle = "->",connectionstyle = "angle,angleA=0,angleB=90,rad=10")

offset = 72
ax.annotate('data = (%.1f, %.1f)'%(xdata, ydata),
            (xdata, ydata), xytext=(-1*offset, offset), textcoords='offset points',
            bbox=bbox, arrowprops=arrowprops)

plt.savefig('myfig.png')
︡b9d411a4-1ecb-41f0-8601-a7a99bd3c1a9︡︡
︠651d9fe3-238e-4aef-a4f6-ac7b3ac727d7︠
#Plot of solution from 2nd order Runge-Kutta approximation using function -sin(t)+x
#This plot has axes range adjusted to give a different view of the solution
︡858b53c5-16a4-452f-b9c8-fdd76020b645︡︡
︠3289cd36-195f-4736-a78e-0fb8e58f8f35︠
new_plxtRK2=plxtRK2 #Name of new plot displaying solution of -sin(t)+x from 2nd order Runge-Kutta approximation
︡1734b529-76d1-46f3-8abd-2c8adf682909︡︡
︠e8fddda8-5cbe-4b6c-8d3b-13955e9566b1︠
#Information to be displayed on 2nd order Runge-Kutta solution of -sin(t)+x with predefined axes range
title1=text("RK2 solution of -sin(t)+x with",(5.2,6),rgbcolor='black',vertical_alignment="top")
title2=text("predefined axis range",(5.2,5.5),rgbcolor='black',vertical_alignment="top")
︡10268ff4-64d5-4bbd-b19d-f8c0b308894e︡︡
︠9351981d-31e6-40e4-a536-8ea8fd2bbca8︠
plxtRK2_new_axes_range=new_plxtRK2+title1+title2 #Variable plxtRK2_new_axes_range set equal to new_plxt2, title, etc.
plxtRK2_new_axes_range.set_axes_range(-2*pi,2*pi, -1,5) #Axes range defined for plxtRK2_new_axes_range.
︡f79b82ec-ef65-4b68-b657-3e1fedfb3bb4︡︡
︠00ea070d-03f8-4658-925f-8fb87ecbdb15︠
show(plxtRK2_new_axes_range,axes_labels=('t','x')) #Displays RK2 solution of -sin(t)+x with axes range predefined.
︡7ae3ce39-0670-4d3c-8345-a44b39a81104︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠a61259b6-b782-4ffd-9823-f4c4d90e4cc2︠
#Plot of solution from 2nd order Runge-Kutta approximation to exact solution of o.d.e
#Solution of 2nd order Runge-Kutta approximation: -sin(t)+x
#Exact Solution: x=sin(t), or x(pi/2)=1
︡3c0d638e-3976-4968-948c-2ac23e5fe0d8︡︡
︠60c15d1e-3a88-4461-b88e-6af1912466ca︠
#Information to display on -sin(t)+x vs sin(pi/2) plot (RK2):
title1=text("RK2 Solution: -sin(t)+x vs",(5,6), rgbcolor='black', vertical_alignment="top")
title2=text("Exact Solution: sin(pi/2)", (5,5.65), rgbcolor='black',vertical_alignment="top")
exact_solution=point((pi/2,1),rgbcolor='red',pointsize=25) #Places red point at exact solution of sin(t) or at (pi/2,1)
︡99bf18e0-7f13-456b-8e8f-2b5e770b7450︡︡
︠523eb58d-fba6-49de-b691-2135443bff0f︠
p1=plot(sin(t),-2*pi,2*pi,linestyle='--') #2D Plot of sin(t) vs t.
RK2_xfunc_vs_exact=plxtRK2+p1 #Set plot of RK2 solution of -sin(t)+x plus sin(t) to RK2_xfunc_vs_exact variable name
plxtRK2_vs_p1=RK2_xfunc_vs_exact+title1+title2+exact_solution #Plot of RK2 solution of function -sin(t)+x vs sin(t)
plxtRK2_vs_p1.set_axes_range(-2*pi,2*pi, -1,5) #Axes range of RK2 solution of function -sin(t)+x vs sin(t) defined
show(plxtRK2_vs_p1,axes_labels=('t','x'))
︡f9069b12-0bd5-4dac-9702-a320a6a15791︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠1e1c301e-77c7-4d6d-80d9-f8618ce95885︠
#Plot of solution from 4th order Runge-Kutta approximation to exact solution of o.d.e
#Solution of 4th order Runge-Kutta approximation: -sin(t)+x
#Exact Solution: x=sin(t), or x(pi/2)=1
︡f1b6e29d-ad48-43a9-9c6e-131382bedb1f︡︡
︠2403d7dc-d523-4e93-90e9-5c9b121266bc︠
#Information to display on -sin(t)+x vs sin(pi/2) plot (RK4):
title1=text("RK4 Solution: -sin(t)+x vs",(5,1.05), rgbcolor='black', vertical_alignment="top")
title2=text("Exact Solution: sin(pi/2)", (5,.9), rgbcolor='black',vertical_alignment="top")
exact_solution=point((pi/2,1),rgbcolor='red',pointsize=25) #Places red point at exact solution of sin(t) or at (pi/2,1)
︡ccfa2e0a-ef6d-4cb1-8768-68a9f98619cf︡︡
︠123ef598-135c-4f94-ac52-cacaf876e936︠
p1=plot(sin(t),-2*pi,2*pi,linestyle='--') #2D Plot of sin(t) vs t.
RK4_xfunc_vs_exact=plxtRK4+p1 #Set plot of RK4 solution of -sin(t)+x plus sin(t) to RK4_xfunc_vs_exact variable name
plxtRK4_vs_p1=RK4_xfunc_vs_exact+title1+title2+exact_solution #Plot of RK4 solution of function -sin(t)+x vs sin(t)
plxtRK4_vs_p1.set_axes_range(-2*pi,2*pi, -1,1.03) #Axes range of RK2 solution of function -sin(t)+x vs sin(t) defined
show(plxtRK4_vs_p1,axes_labels=('t','x'))
︡7bb49dfb-8448-46f7-ad3b-216482aa0f16︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠b2425586-2ab1-47ba-a878-5ba59903fce7︠
def yfunc(t,y): #y function with independent variable t defined. 
    return float(cos(t)-y)
︡3ff1753c-1a7b-48ae-9f3b-456c5910f81b︡︡
︠33fb9125-6698-4339-9486-6bcba898b4fc︠
import scipy #Transfer files from scipy (open source library of algorithms and mathematical tools from Python programming language) into this worksheet.

def rk2y(y0,t0,tn,dt): #2nd Order Runge-Kutta defined.

    time = scipy.arange(t0,tn,dt) # Creates array range (arange) of time values.
    y=[] #Stores index of refraction values.

    for t in time:
        y.append(y0) #Attach results (y0) at end of variable y.
        k1=yfunc(t0,y0)
        k2=yfunc(t+0.5*dt, y0+0.5*k1)
        y0=y0+(k1+k2)/2
    return time,y
︡9fb36b3a-478a-4f0e-8798-496ffd1e8904︡︡
︠d49b6735-7c7a-4f0b-8a14-59eecdd04d77︠
rk2y(0, float(pi/2), 2, 0.01) #Function call to 2nd Order Runge-Kutta with predetermined assignments.
︡73bcdd29-b31c-4962-b4ed-87104c388fb5︡{"stdout": "(array([ 1.57079633,  1.58079633,  1.59079633,  1.60079633,  1.61079633,\n        1.62079633,  1.63079633,  1.64079633,  1.65079633,  1.66079633,\n        1.67079633,  1.68079633,  1.69079633,  1.70079633,  1.71079633,\n        1.72079633,  1.73079633,  1.74079633,  1.75079633,  1.76079633,\n        1.77079633,  1.78079633,  1.79079633,  1.80079633,  1.81079633,\n        1.82079633,  1.83079633,  1.84079633,  1.85079633,  1.86079633,\n        1.87079633,  1.88079633,  1.89079633,  1.90079633,  1.91079633,\n        1.92079633,  1.93079633,  1.94079633,  1.95079633,  1.96079633,\n        1.97079633,  1.98079633,  1.99079633]), [0, -0.0024999895833462543, -0.0081247161490005139, -0.014529876994606204, -0.021128896550819561, -0.027774631156534925, -0.034429795302667515, -0.041084568243058103, -0.04773599569713563, -0.054382840325491857, -0.061024294398651563, -0.067659658014104077, -0.074288258700357879, -0.080909431367703274, -0.087522513345599934, -0.094126843191663145, -0.10072176044348746, -0.10730660560611233, -0.11388072019832604, -0.1204434468136021, -0.12699412918461148, -0.13353211224854183, -0.14005674221252662, -0.14656736661900438, -0.15306333441095948, -0.1595439959970259, -0.16600870331644552, -0.1724568099038736, -0.17888767095402486, -0.18530064338615326, -0.19169508590835971, -0.19807035908172071, -0.20442582538423165, -0.21076084927455843, -0.2170747972555912, -0.2233670379377935, -0.22963694210234056, -0.23588388276404088, -0.24210723523403407, -0.24830637718225917, -0.25448068869968737, -0.26062955236031216, -0.26675235328289149])"}︡
︠a428df6a-4aef-49b7-a421-041bea57bdc2︠
t2,y2=rk2y(0, float(pi/2), 2, 0.01) #Variable t2,y2 is assigned time and y values.
︡cabfe682-3337-4db2-9cd8-9dbad10f28fe︡︡
︠23d152be-a25e-48dd-9351-d1196c636871︠
#Information to display on cos(t)-y plot (RK2):
title=text("RK2 solution of cos(t)-y", (1.86,0.07), rgbcolor='black',vertical_alignment="top")
initial_condition=point((pi/2,0),rgbcolor='red',pointsize=25) #Places red point at initial condition,(pi/2,0)
︡966d7ed0-df2f-44d8-9108-11fd4f7b2b14︡︡
︠310a7a8a-0d25-4eb3-801a-d69fd264aee5︠
plxtRK2=list_plot(zip(t2,y2),'r')
show(plxtRK2+title+initial_condition, axes_labels=('t','y'))
︡5521ed60-a34a-4a1b-bb2d-275db558e240︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠304aa345-87ca-4b74-ab40-681db9daa7f7︠
import numpy as np #Transfer files from fundamental library numpy (N-dimensional array manipulation) used with Python.
import matplotlib.pyplot as plt #Transfer files from matplotlib.pyplot (plotting library) used with Python language. 

x = t2
y = y2

fig = plt.figure()
ax = fig.add_subplot(111)
ax.plot(x, y)
ax.set_xlim(1.4, 2.2)
ax.set_ylim(-0.3, 0.1)
ax.set_xlabel('Increasing time (t)')
ax.set_ylabel('Integrated Eqn: cos(t)-y')
ax.set_title('RK2 Soln to Integrated Eqn: cos(t)-y')
ax.grid()

xdata, ydata = 1.58079633, -0.0024999895833462543
xdisplay, ydisplay = ax.transData.transform((xdata, ydata))

bbox = dict(boxstyle="round", fc="0.8") #bbox or bounding box
arrowprops = dict(arrowstyle = "->",connectionstyle = "angle,angleA=0,angleB=90,rad=10")

offset = 20
ax.annotate('data = (%.1f, %.1f)'%(xdata, ydata),
            (xdata, ydata), xytext=(-1*offset, offset), textcoords='offset points',
            bbox=bbox, arrowprops=arrowprops)

plt.savefig('myfig.png')
︡0b60338d-4e2e-47bb-8e04-6c1ce267de9c︡︡
︠0069f881-b54b-4ff4-bb4e-e3ad78edcd32︠
import scipy #Transfer files from scipy (open source library of algorithms and mathematical tools from Python programming language) into this worksheet.

def rk4y(y0,t0,tn,dt): #4th Order Runge-Kutta defined.

    time = scipy.arange(t0,tn,dt) #Creates array range (arange) of time values.
    y=[] #Stores index of refraction values.

    for t in time:
   	y.append(y0) #Attach results (y0) at end of variable y.
   	k1 = yfunc(t,y0)
   	k2 = yfunc(t+0.5*dt, y0 + 0.5*dt*k1)
   	k3 = yfunc(t+0.5*dt, y0 + 0.5*dt*k2)
   	k4 = yfunc(t+dt, y0 + dt*k3)
   	y0 = y0 +(dt/6.0)*(k1 + 2.0*k2 + 2.0*k3 + k4)
    return time,y
︡034d7e6c-142b-4ab1-a299-a779dc1d0da8︡︡
︠84dd8b45-3367-492a-a2e8-09bc5082b5fd︠
rk4y(0, float(pi/2), 2, 0.01) #Function call to 4th Order Runge-Kutta with predetermined assignments.
︡273aa409-30d8-49cc-8867-ebabca265da4︡{"stdout": "(array([ 1.57079633,  1.58079633,  1.59079633,  1.60079633,  1.61079633,\n        1.62079633,  1.63079633,  1.64079633,  1.65079633,  1.66079633,\n        1.67079633,  1.68079633,  1.69079633,  1.70079633,  1.71079633,\n        1.72079633,  1.73079633,  1.74079633,  1.75079633,  1.76079633,\n        1.77079633,  1.78079633,  1.79079633,  1.80079633,  1.81079633,\n        1.82079633,  1.83079633,  1.84079633,  1.85079633,  1.86079633,\n        1.87079633,  1.88079633,  1.89079633,  1.90079633,  1.91079633,\n        1.92079633,  1.93079633,  1.94079633,  1.95079633,  1.96079633,\n        1.97079633,  1.98079633,  1.99079633]), [0, -0.0000498333340276020, -0.000198666668124114, -0.000445500003036134, -0.000789333341660262, -0.00122916669150976, -0.00176400006815122, -0.00239283349960124, -0.00311466703167308, -0.00392850073426332, -0.00483333470856858, -0.00582816909522210, -0.00691200408334051, -0.00808383992047045, -0.00934267692342526, -0.0106875154900017, -0.0121173561115666, -0.0136311993865036, -0.0152280460345100, -0.0169068969117334, -0.0186667530267384, -0.0205066155572937, -0.0224254858679688, -0.0244223655285313, -0.0264962563331332, -0.0286461603202790, -0.0308710797935620, -0.0331700173431624, -0.0355419758680946, -0.0379859585991946, -0.0405009691228386, -0.0430860114053803, -0.0457400898183003, -0.0484622091640539, -0.0512513747026110, -0.0541065921786752, -0.0570268678495741, -0.0600112085138095, -0.0630586215402586, -0.0661681148980160, -0.0693386971868657, -0.0725693776683751, -0.0758591662975983])"}︡
︠e6c13fe0-cd2d-482f-950c-06c5204f0fcb︠
t4,y4=rk4y(0, float(pi/2), 2, 0.01) #Variable t4,y4 is assigned time and y values.
︡f83ed6c9-d904-47e2-a8b6-108d131ff8e8︡︡
︠fbdb6f2c-961e-49d4-9f74-86b7fa1775de︠
#Information to display on cos(t)-y plot (RK4):
title=text("RK4 solution of cos(t)-y", (1.8,0.01), rgbcolor='black',vertical_alignment="top")
initial_condition=point((pi/2,0),rgbcolor='red',pointsize=25) #Places red point at initial condition,(pi/2,0)
︡e41cfda7-ff1a-4362-b1e9-24a988f02801︡︡
︠f62c3ffb-3e6d-4249-8cee-a12dca7c5f65︠
plxtRK4=list_plot(zip(t4,y4),'r')
show(plxtRK4+title+initial_condition, axes_labels=('t','y'))
︡8ef427bf-f8df-498c-8f39-02377f309bd7︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠e0746edc-d58d-44fe-b838-c31d45f26d44︠
import numpy as np #Transfer files from fundamental library numpy (N-dimensional array manipulation) used with Python.
import matplotlib.pyplot as plt #Transfer files from matplotlib.pyplot (plotting library) used with Python language. 


x = t4
y = y4

fig = plt.figure()
ax = fig.add_subplot(111)
ax.plot(x, y)
ax.set_xlim(1.4, 2.2)
ax.set_ylim(-0.09, 0.03)
ax.set_xlabel('Increasing time (t)')
ax.set_ylabel('Integrated Eqn: cos(t)-y')
ax.set_title('RK4 Soln to Integrated Eqn: cos(t)-y')
ax.grid()

xdata, ydata = 1.58079633, -0.0000498333340276020
xdisplay, ydisplay = ax.transData.transform((xdata, ydata))

bbox = dict(boxstyle="round", fc="0.8") #bbox or bounding box
arrowprops = dict(arrowstyle = "->",connectionstyle = "angle,angleA=0,angleB=90,rad=10")

offset = 50
ax.annotate('data = (%.1f, %.1f)'%(xdata, ydata),
            (xdata, ydata), xytext=(-1*offset, offset), textcoords='offset points',
            bbox=bbox, arrowprops=arrowprops)

plt.savefig('myfig.png')
︡22aa24c7-7d58-46f1-ab6f-e8e6bce98c82︡︡
︠04f3ee35-5148-4d35-9c46-2f860b0ae5a7︠
#Plot of solution from 2nd order Runge-Kutta approximation to exact solution of o.d.e
#Solution of 2nd order Runge-Kutta approximation: cos(t)-y
#Exact Solution: y=cos(t), or y(pi/2)=0
︡34de8efc-7af7-4cef-9ee0-86704e6c7a92︡︡
︠25b13cd6-3fad-4f70-9ba7-60399cb311fb︠
#Information to display on cos(t)-y vs cos(pi/2) plot (RK2):
title1=text("RK2 Solution: cos(t)-y vs",(3,1.2), rgbcolor='black', vertical_alignment="top")
title2=text("Exact Solution: cos(pi/2)", (3,1.05), rgbcolor='black',vertical_alignment="top")
exact_solution=point((pi/2,0),rgbcolor='red',pointsize=25) #Places red point at exact solution of cos(t) or at (pi/2,0)
︡d7df29bc-e3ca-45bf-8288-55a80281fa81︡︡
︠44a45a0e-302c-402d-9fbf-7b0451212948︠
p2=plot(cos(t),-2*pi,2*pi,linestyle='--') #2D Plot of cos(t) vs t.
RK2_yfunc_vs_exact=plxtRK2+p2 #Set plot of RK2 solution of cos(t)-y plus cos(t) to RK2_yfunc_vs_exact variable name
plxtRK2_vs_p2=RK2_yfunc_vs_exact+title1+title2+exact_solution #Plot of RK2 solution of function cos(t)-y vs cos(t)
plxtRK2_vs_p2.set_axes_range(-2*pi,2*pi, -1,1) #Axes range of RK2 solution of function cos(t)-y vs cos(t) defined
show(plxtRK2_vs_p2,axes_labels=('t','y'))
︡cc6f811c-356e-48a7-9e14-3d9b60206401︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠5d3deef0-75f5-420b-bb9c-1cc62de7f623︠
#Plot of solution from 4th order Runge-Kutta approximation to exact solution of o.d.e
#Solution of 4th order Runge-Kutta approximation: cos(t)-y
#Exact Solution: y=cos(t), or y(pi/2)=0
︡647eeafd-3c1d-482d-a546-20bd247f4c10︡︡
︠894457d4-279b-4c2e-8e19-31afa40581f3︠
#Information to display on cos(t)-y vs cos(pi/2) plot (RK4):
title1=text("RK4 Solution: cos(t)-y vs",(3,1.2), rgbcolor='black', vertical_alignment="top")
title2=text("Exact Solution: cos(pi/2)", (3,1.05), rgbcolor='black',vertical_alignment="top")
exact_solution=point((pi/2,0),rgbcolor='red',pointsize=25) #Places red point at exact solution of cos(t) or at (pi/2,0)
︡7e887150-9597-4fd1-a11e-933c01d4b9f7︡︡
︠491ace7c-14d4-41e6-943a-efd22026765e︠
p2=plot(cos(t),-2*pi,2*pi,linestyle='--') #2D Plot of cos(t) vs t.
RK4_yfunc_vs_exact=plxtRK4+p2 #Set plot of RK4 solution of cos(t)-y plus cos(t) to RK4_yfunc_vs_exact variable name
plxtRK4_vs_p2=RK4_yfunc_vs_exact+title1+title2+exact_solution #Plot of RK4 solution of function cos(t)-y vs cos(t)
plxtRK4_vs_p2.set_axes_range(-2*pi,2*pi, -1,1) #Axes range of RK4 solution of function cos(t)-y vs cos(t) defined
show(plxtRK4_vs_p2,axes_labels=('t','y'))
︡4c563543-393e-4a9b-9eb3-99fe1c63d0e3︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
